@@ -36,11 +36,17 @@ elapsed_time = sys.argv[4]
 separator = App().config.plugins.categories.separator
 
 try:
-    category, name = archive_name.split(separator)
-except ValueError:
+    parts = archive_name.split(separator)
+    category = parts[0]
+    name = parts[1]
+except IndexError:
     pass
 else:
     if not success:
         category = _("Failed")
     
-    move(dest_dir, join(dirname(dest_dir), category, name))
+    # Due to the change of the configuration system, the category separator
+    # was changed from ' -- ' to '--' which caused all downloads that were
+    # added with LottaNZB < 0.4.0 to have a trailing space in their
+    # category directory and a leading space in the actual download directory.
+    move(dest_dir, join(dirname(dest_dir), category.strip(), name.strip()))
